# ingreedy-py [![Coverage Status](https://coveralls.io/repos/scttcper/ingreedy-py/badge.svg?branch=master&service=github)](https://coveralls.io/github/scttcper/ingreedy-py?branch=master)
python port of https://github.com/iancanderson/ingreedy-js

## Installation
```bash
pip install ingreedypy
```

To run tests ```coverage run --source=ingreedypy setup.py test```
